﻿/*
 * Copyright (C) 2016 xuld<xuld@vip.qq.com>
 *
 * Permission is hereby granted, free of charge, to any person 
 * obtaining a copy of this software and associated documentation 
 * files (the "Software"), to deal in the Software without restriction, 
 * including without limitation the rights to use, copy, modify, merge, 
 * publish, distribute, sublicense, and/or sell copies of the Software, 
 * and to permit persons to whom the Software is furnished to do so, 
 * subject to the following conditions:
 *　
 * The above copyright notice and this permission notice shall be 
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 *
 */

var TypeScript = require("typescript");

/**
 * 编译 TypeScript。
 * @param {BuildFile} file 要生成的文件。
 * @param {Object} options 相关的选项。
 * @see http://www.typescriptlang.org/docs/handbook/compiler-options.html
 * @see https://github.com/Microsoft/TypeScript/wiki/Using-the-Compiler-API
 */
module.exports = function typeScript(file, options) {

    // 设置默认值。
    options = {
        compilerOptions: Object.assign({
            allowNonTsExtensions: true,
            sourceMap: !!file.sourceMap,
            noImplicitUseStrict: !options.strict,
            charset: file.encoding,
            jsx: /x$/i.test(file.srcName) ? 2/*React*/ : 1/*Preserve*/
        }, options),
        fileName: file.srcPath,
        reportDiagnostics: true
    };

    // 更改扩展名。
    file.extension = ".js";

    // 生成。
    var result = TypeScript.transpileModule(file.content, options);

    // 报告错误。
    for (var i = 0; i < result.diagnostics.length; i++) {
        var diagnostic = result.diagnostics[i];
        var startLoc = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start);
        var endLoc = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start + diagnostic.length);
        diagnostic.name = "TypeScriptError";
        diagnostic.message = diagnostic.messageText;
        diagnostic.fileName = diagnostic.file.fileName;
        diagnostic.startLine = startLoc.line + 1;
        diagnostic.startColumn = startLoc.character;
        diagnostic.endLine = endLoc.line + 1;
        diagnostic.endColumn = endLoc.character;
        diagnostic.map = true;
        file.error(diagnostic);
    }

    // 保存。
    file.content = result.outputText;
    if (result.sourceMapText) {
        file.applySourceMap(result.sourceMapText);
    }
};
